=======
GroupBy
=======

This namespace becomes available by calling `DataFrame.group_by(...)`.

.. currentmodule:: polars.dataframe.group_by
.. autosummary::
   :toctree: api/

    GroupBy.__iter__
    GroupBy.agg
    GroupBy.all
    GroupBy.count
    GroupBy.first
    GroupBy.head
    GroupBy.last
    GroupBy.len
    GroupBy.map_groups
    GroupBy.max
    GroupBy.mean
    GroupBy.median
    GroupBy.min
    GroupBy.n_unique
    GroupBy.quantile
    GroupBy.sum
    GroupBy.tail
